import { useCallback, useEffect, useRef } from "react"

/**
 * 定时器
 * 执行一系列的函数
 * @param {*} interval 
 * @returns
 */
export default function useInterval(interval) {

  // 待执行函数列表
  const fnListRef = useRef([])

  // 暴露出一个方法来添加待执行函数
  const push = useCallback((fn) => {
    fnListRef.current.push(fn)

    return () => {
      const inx = fnListRef.current.indexOf(fn)
      fnListRef.current.splice(inx)
    }
  }, [])

  useEffect(() => {
    const ticker = setInterval(() => {
      console.log('-----------interval---------')
      fnListRef.current.forEach(fn => fn())
    }, interval)
    return () => clearInterval(ticker)
  }, [])

  return [push]
}
