
import { useState, useRef, useMemo, useCallback, useEffect } from 'react'
import Taro, { useDidHide, useDidShow } from '@tarojs/taro'
import { throttle } from '@/utils'
import newShake from '@/utils/shake'

export default function useShake() {
  const [times, setTimes] = useState(0)
  const timesRef = useRef(times)
  const isReadyRef = useRef(false)
  const lastTimeRef = useRef()

  const onShake = useMemo(() => newShake().onShake, [])

  // eslint-disable-next-line react-hooks/exhaustive-deps
  const handleShake = useCallback(throttle((val) => {
    setTimes(val)
  }, 1300, { trailing: true, immediate: true }), [])

  const start = useCallback(() => {
    isReadyRef.current = true
    timesRef.current = 0
    setTimes(0)
  }, [])

  const handleEndRef = useRef()
  const onEnd = useCallback(callback => handleEndRef.current = callback, [])

  useEffect(() => {
    const interval = setInterval(() => {
      if (isReadyRef.current) {
        const now = new Date()

        // 超过 1s 就算停止摇动了
        if (lastTimeRef.current && now - lastTimeRef.current >= 1000) {
          if (handleEndRef.current) {
            setTimes(timesRef.current)
            handleEndRef.current()
            lastTimeRef.current = undefined
          }
          isReadyRef.current = false
        }
      }
    }, 1000)

    return () => clearInterval(interval)
  }, [])

  useDidShow(() => {
    Taro.startAccelerometer()

    Taro.onAccelerometerChange((e) => {
      if (isReadyRef.current) {
        onShake(e, () => {
          timesRef.current += 1
          console.log('--->times: ', timesRef.current)
          handleShake(timesRef.current)
          lastTimeRef.current = new Date()
        })
      }
    })
  })

  useDidHide(() => {
    Taro.startAccelerometer()
  })

  return [times, start, onEnd]
}
