
export function throttle(fn, delay, options = {}) {
    let timer = null;
    let last = 0;

    return function () {
        const context = this;
        const args = arguments;

        const now = +new Date();

        if (last === 0 && options.immediate === false) {
            last = now;
        }

        const offset = now - last;

        if (offset > delay) {
            if (timer) {
                clearTimeout(timer);
                timer = null;
            }

            last = now;
            fn.apply(context, args);
        }
        else if (!timer && options.trailing !== false) {
            timer = setTimeout(() => {
                last = options.immediate === false ? 0 : +new Date();;
                timer = null;
                fn.apply(context, args);
            }, delay - offset);
        }
    };
}



/**
 * object 转 queryStr
 * @param {*} params 
 * @returns 
 */
export function getQueryString(params) {
    if (!params) return;

    const keys = Object.keys(params)
    const arr = keys.map((key) => {
        const val = params[key]
        if (val === null || val === undefined) return false;

        return `${key}=${encodeURIComponent(val)}`
    })

    return arr.filter(Boolean).join('&')
}

