import Taro from "@tarojs/taro";
import { getQueryString } from ".";



export default (url, options) => {
  const { params, header, ...leftOptions } = options || {}


  const queryStr = getQueryString(params)

  const urlWithParams = queryStr ? `${url}?${queryStr}` : url;
  const nwUrl = `${HOST}/api${urlWithParams}`

  const authToken = Taro.getStorageSync('token')
  const tokenHeader = authToken ? { 'X-Authorization-JWT': authToken } : {}
  const nwHeader = {
    ...(header || {}),
    ...tokenHeader,
  }




  return new Promise((resolve, reject) => {
    Taro.request({
      ...leftOptions,
      url: nwUrl,
      header: nwHeader,
      success: (res) => {
        const { code, message, data, token } = res.data
        if (token || data?.token) {
          Taro.setStorage({ key: 'token', data: token || data?.token })
        }
        if (code === 1000) {
          resolve(data)
        } else {
          console.error(res)


          reject(message?.indexOf('java') > -1 ? '系统内部错误' : message)
        }
      },

      fail: (err) => {
        const message = err.message || err.errMsg || err

        reject(message)
      }
    })
  })

}